@@ -12,6 +12,7 @@ map:
   configuration: {type: any}
   koji_target: {type: str}
   extra_dir: {type: str}
+  extra_dir_target: {type: str}
 
 """)
 
@@ -29,6 +30,7 @@ repository_schema = yaml.safe_load("""
 
 logger = logging.getLogger('cekit')
 
+
 class Osbs(Descriptor):
     """
     Object Representing OSBS configuration
@@ -49,6 +51,14 @@ class Osbs(Descriptor):
         self['repository'] = Repository(self._descriptor.get(
             'repository', {}), self.descriptor_path)
 
+    def merge(self, descriptor):
+        if not descriptor:
+            return self
+        for k2, v2 in descriptor.items():
+            if v2:
+                self[k2] = v2
+        return self
+
     @property
     def name(self):
         return self.get('name')
@@ -77,6 +87,14 @@ class Osbs(Descriptor):
     def extra_dir(self, value):
         self._descriptor['extra_dir'] = value
 
+    @property
+    def extra_dir_target(self):
+        return self.get('extra_dir_target')
+
+    @extra_dir_target.setter
+    def extra_dir_target(self, value):
+        self._descriptor['extra_dir_target'] = value
+
     @property
     def koji_target(self):
         return self.get('koji_target')
@@ -116,6 +134,7 @@ class Configuration(Descriptor):
         if remote_source:
             logger.debug("Cachito definition is {}".format(remote_source))
 
+
 class Repository(Descriptor):
     def __init__(self, descriptor, descriptor_path):
         self.schema = repository_schema
